@@ -2,15 +2,15 @@
 """
 hardware implementation of the PyNN API.
 It includes the submodules that stand on another directory.
-This solution is a clean way to make the submodules (brainscales, etc...) 
+This solution is a clean way to make the submodules (brainscales, etc...)
 be indeed submodules of hardware, even if they don't stand on the same directory
 
-:copyright: Copyright 2006-2019 by the PyNN team, see AUTHORS.
+:copyright: Copyright 2006-2020 by the PyNN team, see AUTHORS.
 :license: CeCILL, see LICENSE for details.
 
 """
 
-from aux import get_path_to_analog_hardware_backend, import_all_submodules
+from auxiliary import get_path_to_analog_hardware_backend, import_all_submodules
 
 __path__.append(get_path_to_analog_hardware_backend())
 import_all_submodules(__path__)
