@@ -15,7 +15,7 @@ Attributes:
 All other functions and classes are private, and should not be used by other
 modules.
 
-:copyright: Copyright 2006-2019 by the PyNN team, see AUTHORS.
+:copyright: Copyright 2006-2020 by the PyNN team, see AUTHORS.
 :license: CeCILL, see LICENSE for details.
 
 """
@@ -35,9 +35,9 @@ from operator import itemgetter
 logger = logging.getLogger("PyNN")
 name = "NEURON"  # for use in annotating output data
 
-# Instead of starting the projection var-GID range from 0, the first _MIN_PROJECTION_VARGID are 
+# Instead of starting the projection var-GID range from 0, the first _MIN_PROJECTION_VARGID are
 # reserved for other potential uses
-_MIN_PROJECTION_VARGID = 1000000 
+_MIN_PROJECTION_VARGID = 1000000
 
 # --- Internal NEURON functionality --------------------------------------------
 
@@ -274,8 +274,8 @@ class _State(common.control.BaseState):
 
     def get_vargids(self, projection, pre_idx, post_idx):
         """
-        Get new "variable"-GIDs (as opposed to the "cell"-GIDs) for a given pre->post connection 
-        pair for a given projection. 
+        Get new "variable"-GIDs (as opposed to the "cell"-GIDs) for a given pre->post connection
+        pair for a given projection.
 
         `projection`  -- projection
         `pre_idx`     -- index of the presynaptic cell
@@ -287,12 +287,12 @@ class _State(common.control.BaseState):
             # Get the projection with the current maximum vargid offset
             if len(self.vargid_offsets):
                 newest_proj, offset = max(self.vargid_offsets.items(), key=itemgetter(1))
-                # Allocate it a large enough range for a mutual all-to-all connection (assumes that 
+                # Allocate it a large enough range for a mutual all-to-all connection (assumes that
                 # there are no duplicate pre_idx->post_idx connections for the same projection. If
                 # that is really desirable a new projection will need to be used)
                 offset += 2 * len(newest_proj.pre) * len(newest_proj.post)
             else:
-                offset = _MIN_PROJECTION_VARGID 
+                offset = _MIN_PROJECTION_VARGID
             self.vargid_offsets[projection] = offset
         pre_post_vargid = offset + 2 * (pre_idx + post_idx * len(projection.pre))
         post_pre_vargid = pre_post_vargid + 1
@@ -463,46 +463,46 @@ class GapJunction(object):
         self.postsynaptic_index = post
         segment_name = projection.receptor_type
         # Strip 'gap' string from receptor_type (not sure about this, it is currently appended to
-        # the available synapse types in the NCML model segments but is not really necessary and 
+        # the available synapse types in the NCML model segments but is not really necessary and
         # it feels a bit hacky but it makes the list of receptor types more comprehensible)
-        if segment_name.endswith('.gap'): 
+        if segment_name.endswith('.gap'):
             segment_name = segment_name[:-4]
         self.segment = getattr(projection.post[post]._cell, segment_name)
         pre_post_vargid, post_pre_vargid = state.get_vargids(projection, pre, post)
-        self._make_connection(self.segment, parameters.pop('weight'), pre_post_vargid,   
+        self._make_connection(self.segment, parameters.pop('weight'), pre_post_vargid,
                               post_pre_vargid, projection.pre[pre], projection.post[post])
-        
+
     def _make_connection(self, segment, weight, local_to_remote_vargid, remote_to_local_vargid,
-                         local_gid, remote_gid):       
+                         local_gid, remote_gid):
         logger.debug("Setting source_var on local cell {} to connect to target_var on remote "
                      "cell {} with vargid {} on process {}"
-                    .format(local_gid, remote_gid, local_to_remote_vargid, 
+                    .format(local_gid, remote_gid, local_to_remote_vargid,
                             state.mpi_rank))
-        # Set up the source reference for the local->remote connection 
-        state.parallel_context.source_var(segment(0.5)._ref_v, local_to_remote_vargid)              
+        # Set up the source reference for the local->remote connection
+        state.parallel_context.source_var(segment(0.5)._ref_v, local_to_remote_vargid)
         # Create the gap_junction and set its weight
         self.gap = h.Gap(0.5, sec=segment)
         self.gap.g = weight
         # Connect the gap junction with the source_var
         logger.debug("Setting target_var on local cell {} to connect to source_var on remote "
                      "cell {} with vargid {} on process {}"
-                    .format(local_gid, remote_gid, remote_to_local_vargid, 
+                    .format(local_gid, remote_gid, remote_to_local_vargid,
                             state.mpi_rank))
         # set up the target reference for the remote->local connection
         state.parallel_context.target_var(self.gap._ref_vgap, remote_to_local_vargid)
-        
+
     def _set_weight(self, w):
         self.gap.g = w
 
     def _get_weight(self):
         """Gap junction conductance in µS."""
         return self.gap.g
-    
+
     weight = property(_get_weight, _set_weight)
-    
+
     def as_tuple(self, *attribute_names):
         return tuple(getattr(self, name) for name in attribute_names)
-    
+
 
 class GapJunctionPresynaptic(GapJunction):
     """
@@ -510,19 +510,19 @@ class GapJunctionPresynaptic(GapJunction):
     so it shares its functionality with the GapJunction connection object, with the exception that
     the pre and post synaptic cells are switched
     """
-    
+
     def __init__(self, projection, pre, post, **parameters):
         self.presynaptic_index = pre
         self.postsynaptic_index = post
-        if projection.source.endswith('.gap'): 
+        if projection.source.endswith('.gap'):
             segment_name = projection.source[:-4]
         else:
             segment_name = projection.source
         self.segment = getattr(projection.pre[pre]._cell, segment_name)
         pre_post_vargid, post_pre_vargid = state.get_vargids(projection, pre, post)
-        self._make_connection(self.segment, parameters.pop('weight'), post_pre_vargid, 
+        self._make_connection(self.segment, parameters.pop('weight'), post_pre_vargid,
                               pre_post_vargid, projection.post[post], projection.pre[pre])
-    
+
 
 def generate_synapse_property(name):
     def _get(self):
@@ -531,12 +531,12 @@ def generate_synapse_property(name):
     def _set(self, val):
         setattr(self.weight_adjuster, name, val)
     return property(_get, _set)
-setattr(Connection, 'w_max', generate_synapse_property('wmax'))
-setattr(Connection, 'w_min', generate_synapse_property('wmin'))
-setattr(Connection, 'A_plus', generate_synapse_property('aLTP'))
-setattr(Connection, 'A_minus', generate_synapse_property('aLTD'))
-setattr(Connection, 'tau_plus', generate_synapse_property('tauLTP'))
-setattr(Connection, 'tau_minus', generate_synapse_property('tauLTD'))
+setattr(Connection, 'wmax', generate_synapse_property('wmax'))
+setattr(Connection, 'wmin', generate_synapse_property('wmin'))
+setattr(Connection, 'aLTP', generate_synapse_property('aLTP'))
+setattr(Connection, 'aLTD', generate_synapse_property('aLTD'))
+setattr(Connection, 'tauLTP', generate_synapse_property('tauLTP'))
+setattr(Connection, 'tauLTD', generate_synapse_property('tauLTD'))
 setattr(Connection, 'U', generate_synapse_property('U'))
 setattr(Connection, 'tau_rec', generate_synapse_property('tau_rec'))
 setattr(Connection, 'tau_facil', generate_synapse_property('tau_facil'))
