@@ -41,7 +41,11 @@ try:
 except NameError:  # Python 3
     basestring = str
 
-import h5py
+try:
+    import h5py
+    HAVE_H5PY = True
+except ImportError:
+    HAVE_H5PY = False
 import numpy as np
 from pyNN.network import Network
 from pyNN.parameters import Sequence
@@ -69,6 +73,8 @@ class SonataIO(BaseIO):
                  spikes_sort_order=None,
                  report_config=None,
                  node_sets=None):
+        if not HAVE_H5PY:
+            raise Exception("You need to install h5py to use SonataIO")
         self.base_dir = base_dir
         self.spike_file = spikes_file
         self.spikes_sort_order = spikes_sort_order
@@ -88,7 +94,7 @@ class SonataIO(BaseIO):
         segment = neo.Segment(file_origin=file_path)
         spikes_file = h5py.File(file_path, 'r')
         for gid in np.unique(spikes_file['spikes']['gids']):
-            index = spikes_file['spikes']['gids'].value == gid
+            index = spikes_file['spikes']['gids'][()] == gid
             spike_times = spikes_file['spikes']['timestamps'][index]
             segment.spiketrains.append(
                 neo.SpikeTrain(spike_times,
@@ -190,6 +196,12 @@ def cast(value):
     return value
 
 
+def to_string(s):
+    if isinstance(s, bytes):
+        s = s.decode('utf-8')
+    return s
+
+
 def read_types_file(file_path, node_or_edge):
     """Read node type or edge type parameters from a SONATA CSV file.
 
@@ -317,6 +329,8 @@ def export_to_sonata(network, output_path, target="PyNN", overwrite=False):
     as an implicit Assembly with a single member, at the cost of losing some information about
     the PyNN network structure. This approach could be improved in future.
     """
+    if not HAVE_H5PY:
+        raise Exception("You need to install h5py to use SONATA")
 
     # --- define directory layout ---
     config = {
@@ -386,14 +400,17 @@ def export_to_sonata(network, output_path, target="PyNN", overwrite=False):
         node_type_info = {
             "node_type_id": i,
         }
-        if target.lower() == "neuron":
-            node_type_info["model_type"] = "single_compartment"
-        elif target.lower() in ("pynn", "nest"):
-            node_type_info["model_type"] = "point_neuron"
-            node_type_info["model_template"] = "{}:{}".format(target.lower(),
-                                                              population.celltype.__class__.__name__)
+        if "SpikeSource" in population.celltype.__class__.__name__:
+            node_type_info["model_type"] = "virtual"
         else:
-            raise NotImplementedError
+            if target.lower() == "neuron":
+                node_type_info["model_type"] = "single_compartment"
+            elif target.lower() in ("pynn", "nest"):
+                node_type_info["model_type"] = "point_neuron"
+                node_type_info["model_template"] = "{}:{}".format(target.lower(),
+                                                                population.celltype.__class__.__name__)
+            else:
+                raise NotImplementedError
         group_label = 0  #"default"
         # todo: add "population" column
 
@@ -414,16 +431,19 @@ def export_to_sonata(network, output_path, target="PyNN", overwrite=False):
         node_group = default.create_group(str(group_label))
         node_params_group = node_group.create_group("dynamics_params")
         for parameter_name in population.celltype.default_parameters:
-            # we could make a single get call to get all params at once, at the expense
-            # of higher memory usage. To profile...
-            values = population.get(parameter_name, gather=True, simplify=True)
-            if isinstance(values, np.ndarray):
-                # array, put into the HDF5 file and put 'NONE' in the CSV file
-                node_params_group.create_dataset(parameter_name, data=values)
-                node_type_info[parameter_name] = "NONE"
+            if parameter_name == "spike_times":
+                warn("spike times should be added manually to simulation_config")
             else:
-                # scalar, put into the CSV file
-                node_type_info[parameter_name] = values
+                # we could make a single get call to get all params at once, at the expense
+                # of higher memory usage. To profile...
+                values = population.get(parameter_name, gather=True, simplify=True)
+                if isinstance(values, np.ndarray):
+                    # array, put into the HDF5 file and put 'NONE' in the CSV file
+                    node_params_group.create_dataset(parameter_name, data=values)
+                    node_type_info[parameter_name] = "NONE"
+                else:
+                    # scalar, put into the CSV file
+                    node_type_info[parameter_name] = values
 
         # positions in space
         x, y, z = population.positions
@@ -457,8 +477,8 @@ def export_to_sonata(network, output_path, target="PyNN", overwrite=False):
     for i, projection in enumerate(network.projections):
         projection_label = asciify(projection.label)
         config["networks"]["edges"].append({
-            "edges_file": "$NETWORK_DIR/edges_{}.h5".format(projection_label.decode('utf-8')),
-            "edge_types_file": "$NETWORK_DIR/edge_types_{}.csv".format(projection_label.decode('utf-8'))
+            "edges_file": "$NETWORK_DIR/edges_{}.h5".format(projection_label),
+            "edge_types_file": "$NETWORK_DIR/edge_types_{}.csv".format(projection_label)
         })
         edge_type_path = Template(config["networks"]["edges"][i]["edge_types_file"]).substitute(NETWORK_DIR=network_dir)
         edges_path = Template(config["networks"]["edges"][i]["edges_file"]).substitute(NETWORK_DIR=network_dir)
@@ -541,6 +561,9 @@ def import_from_sonata(config_file, sim):
     We map a SONATA edge group to a PyNN Projection, i.e. a SONATA edge population may
     result in multiple PyNN Projections.
     """
+    if not HAVE_H5PY:
+        raise Exception("You need to install h5py to use SONATA")
+
     config = load_config(config_file)
 
     if config.get("target_simulator", None) not in  ("PyNN", "NEST"):
@@ -639,12 +662,13 @@ class NodePopulation(object):
         obj.node_groups = []
         obj.node_ids = h5_data['node_id']
 
-        for ng_label in np.unique(h5_data['node_group_id'].value):
-            mask = h5_data['node_group_id'].value == ng_label
+        node_group_ids = h5_data['node_group_id'][()]
+        for ng_label in np.unique(node_group_ids):
+            mask = node_group_ids == ng_label
             logger.info("NODE GROUP {}, size {}".format(ng_label, mask.sum()))
 
             node_type_array = h5_data['node_type_id'][mask]
-            node_group_index = h5_data['node_group_index'][mask]
+            node_group_index = h5_data['node_group_index'][mask].tolist()
             obj.node_groups.append(
                 NodeGroup.from_data(ng_label,
                                     node_type_array,
@@ -665,7 +689,7 @@ class NodePopulation(object):
         The Assembly will contain one Population for each NodeGroup.
         """
         assembly = sim.Assembly(label=self.name)
-        assembly.annotations["first_sonata_id"] = self.node_ids.value.min()
+        assembly.annotations["first_sonata_id"] = self.node_ids[()].min()
         for node_group in self.node_groups:
             pop = node_group.to_population(sim)
             assembly += pop
@@ -694,7 +718,7 @@ class NodeGroup(object):
         node_types_array : NumPy array
             Subset of the data from "/nodes/<population_name>/node_type_id"
             that applies to this group.
-        index : NumPy array
+        index : list
             Subset of the data from "/nodes/<population_name>/node_group_index"
             that applies to this group.
         h5_data : HDF5 Group
@@ -733,7 +757,7 @@ class NodeGroup(object):
             dynamics_params_group = h5_data['dynamics_params']
             # not sure the next bit is using `index` correctly
             for key in dynamics_params_group.keys():
-                parameters[key] = dynamics_params_group[key].value[index]
+                parameters[key] = dynamics_params_group[key][index]
 
         obj.parameters = parameters
         obj.config = config
@@ -828,18 +852,18 @@ class EdgePopulation(object):
 
         obj = cls()
         obj.name = name
-        obj.source_node_ids = h5_data["source_node_id"].value
-        obj.source_node_population = h5_data["source_node_id"].attrs["node_population"].decode('utf-8')
-        obj.target_node_ids = h5_data["target_node_id"].value
-        obj.target_node_population = h5_data["target_node_id"].attrs["node_population"].decode('utf-8')
+        obj.source_node_ids = h5_data["source_node_id"][()]
+        obj.source_node_population = to_string(h5_data["source_node_id"].attrs["node_population"])
+        obj.target_node_ids = h5_data["target_node_id"][()]
+        obj.target_node_population = to_string(h5_data["target_node_id"].attrs["node_population"])
 
         obj.edge_groups = []
-        for eg_label in np.unique(h5_data['edge_group_id'].value):
-            mask = h5_data['edge_group_id'].value == eg_label
+        for eg_label in np.unique(h5_data['edge_group_id'][()]):
+            mask = h5_data['edge_group_id'][()] == eg_label
             logger.info("EDGE GROUP {}, size {}".format(eg_label, mask.sum()))
 
             edge_type_array = h5_data['edge_type_id'][mask]
-            edge_group_index = h5_data['edge_group_index'][mask]
+            edge_group_index = h5_data['edge_group_index'][mask].tolist()
             source_ids = obj.source_node_ids[mask]
             target_ids = obj.target_node_ids[mask]
             # note: it may be more efficient in an MPI context
@@ -889,7 +913,7 @@ class EdgeGroup(object):
         node_types_array : NumPy array
             Subset of the data from "/edges/<population_name>/edge_type_id"
             that applies to this group.
-        index : NumPy array
+        index : list
             Subset of the data from "/edges/<population_name>/edge_group_index"
             that applies to this group.
         h5_data : HDF5 Group
@@ -930,11 +954,11 @@ class EdgeGroup(object):
             dynamics_params_group = h5_data['dynamics_params']
             # not sure the next bit is using `index` correctly
             for key in dynamics_params_group.keys():
-                parameters[key] = dynamics_params_group[key].value[index]
+                parameters[key] = dynamics_params_group[key][index]
         if 'nsyns' in h5_data:
-            parameters['nsyns'] = h5_data['nsyns'].value[index]
+            parameters['nsyns'] = h5_data['nsyns'][index]
         if 'syn_weight' in h5_data:
-            parameters['syn_weight'] = h5_data['syn_weight'].value[index]
+            parameters['syn_weight'] = h5_data['syn_weight'][index]
 
         obj.parameters = parameters
         obj.config = config
